@@ -20,8 +20,8 @@ protected:
 		
 		const BaselineStatisticsMap& map = statCollection->BaselineStatistics();
 		
-		vector<std::pair<unsigned, unsigned> > baselines = map.BaselineList();
-		for(vector<std::pair<unsigned, unsigned> >::const_iterator i=baselines.begin();i!=baselines.end();++i)
+		std::vector<std::pair<unsigned, unsigned> > baselines = map.BaselineList();
+		for(std::vector<std::pair<unsigned, unsigned> >::const_iterator i=baselines.begin();i!=baselines.end();++i)
 		{
 			Baseline bline(antennas[i->first], antennas[i->second]);
 			const DefaultStatistics &statistics = map.GetStatistics(i->first, i->second);
