@@ -7,7 +7,7 @@
 class VdsFile
 {
 	public:
-		VdsFile(const std::string &path);
+		explicit VdsFile(const std::string &path);
 		
 		size_t NParts() const;
 		std::string Host(size_t partIndex) const;
