@@ -9,12 +9,12 @@ namespace rfiStrategy {
 	
 void FrequencySelectionAction::Perform(ArtifactSet &artifacts, class ProgressListener &)
 {
-	const Image2D* image = artifacts.ContaminatedData().GetSingleImage().get();
+	Image2DCPtr image = artifacts.ContaminatedData().GetSingleImage();
 	SampleRow channels = SampleRow::MakeEmpty(image->Height());
 	Mask2DPtr mask(new Mask2D(*artifacts.ContaminatedData().GetSingleMask()));
 	for(size_t y=0;y<image->Height();++y)
 	{
-		SampleRow row = SampleRow::MakeFromRowWithMissings(image, mask.get(), y);
+		SampleRow row = SampleRow::MakeFromRowWithMissings(image.get(), mask.get(), y);
 		channels.SetValue(y, row.RMSWithMissings());
 	}
 	bool change;
