@@ -3,6 +3,8 @@
 #include "../../structures/date.h"
 #include "../../structures/system.h"
 
+#include "../control/defaultstrategy.h"
+
 #include <fstream>
 
 namespace rfiStrategy {
@@ -180,6 +182,11 @@ void FilterBankSet::AddWriteFlagsTask(const ImageSetIndex& index, std::vector<Ma
 	}
 }
 
+std::string FilterBankSet::TelescopeName()
+{
+	return DefaultStrategy::TelescopeName(DefaultStrategy::GENERIC_TELESCOPE);
+}
+
 void FilterBankSet::Initialize()
 {
 }
