@@ -2,6 +2,7 @@
 #define XYSWAPPEDMASK2D_H
 
 #include "mask2d.h"
+#include "image2d.h"
 
 /**
  * This class wraps a mask and swappes the x and y axes. It provides only the
@@ -17,35 +18,79 @@
  * 
  * @author Andre Offringa
  */
+template<typename MaskLike>
 class XYSwappedMask2D
 {
 	public:
-		explicit XYSwappedMask2D(Mask2D &mask) : _mask(mask)
+		explicit XYSwappedMask2D(MaskLike &mask) : _mask(mask)
 		{
 		}
 		
-		inline bool Value(unsigned x, unsigned y) const
+		XYSwappedMask2D<MaskLike>& operator=(const XYSwappedMask2D<MaskLike>& source)
+		{
+			_mask = source._mask;
+			return *this;
+		}
+		
+		bool Value(unsigned x, unsigned y) const
 		{
 			return _mask.Value(y, x);
 		}
 		
-		inline void SetValue(unsigned x, unsigned y, bool newValue)
+		void SetValue(unsigned x, unsigned y, bool newValue)
 		{
 			_mask.SetValue(y, x, newValue);
 		}
 		
-		inline unsigned Width() const
+		void SetHorizontalValues(unsigned x, unsigned y, bool value, unsigned count)
+		{
+			_mask.SetVerticalValues(y, x, value, count);
+		}
+		
+		unsigned Width() const
 		{
 			return _mask.Height();
 		}
 		
-		inline unsigned Height() const
+		unsigned Height() const
 		{
 			return _mask.Width();
 		}
 		
 	private:
-		Mask2D &_mask;
+		MaskLike &_mask;
+};
+
+template<typename ImageLike>
+class XYSwappedImage2D
+{
+	public:
+		explicit XYSwappedImage2D(ImageLike &image) : _image(image)
+		{
+		}
+		
+		inline num_t Value(unsigned x, unsigned y) const
+		{
+			return _image.Value(y, x);
+		}
+		
+		inline void SetValue(unsigned x, unsigned y, num_t newValue)
+		{
+			_image.SetValue(y, x, newValue);
+		}
+		
+		inline unsigned Width() const
+		{
+			return _image.Height();
+		}
+		
+		inline unsigned Height() const
+		{
+			return _image.Width();
+		}
+		
+	private:
+		ImageLike &_image;
 };
 
 #endif // XYSWAPPEDMASK2D_H
